@@ -17,8 +17,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
 #include "atkhyperlink.h"
-#include "atkintl.h"
+#include <glib/gi18n-lib.h>
 
 /**
  * SECTION:atkhyperlink
@@ -116,10 +117,8 @@ atk_hyperlink_class_init (AtkHyperlinkClass *klass)
    *
    * Selected link
    *
-   * Deprecated: Since 1.8. This property is deprecated since ATK
-   * version 1.8. Please use ATK_STATE_FOCUSABLE for all links, and
+   * Deprecated: 1.8: Please use ATK_STATE_FOCUSABLE for all links, and
    * ATK_STATE_FOCUSED for focused links.
-   *
    */
   g_object_class_install_property (gobject_class,
                                    PROP_SELECTED_LINK,
@@ -343,7 +342,7 @@ atk_hyperlink_is_valid (AtkHyperlink *link)
  *           content inline.  Ordinary HTML links will usually return
  *           %FALSE, but an inline &lt;src&gt; HTML element will return
  *           %TRUE.
-a *
+ *
  * Returns: whether or not this link displays its content inline.
  *
  **/
@@ -391,11 +390,10 @@ atk_hyperlink_get_n_anchors (AtkHyperlink *link)
  *
  * Since: 1.4
  *
- * Deprecated: This method is deprecated since ATK version 1.8.
- * Please use ATK_STATE_FOCUSABLE for all links, and ATK_STATE_FOCUSED
- * for focused links.
+ * Deprecated: 1.8: Please use ATK_STATE_FOCUSABLE for all links,
+ * and ATK_STATE_FOCUSED for focused links.
  *
- * Returns: True is the AtkHyperlink is selected, False otherwise
+ * Returns: True if the AtkHyperlink is selected, False otherwise
  **/
 gboolean
 atk_hyperlink_is_selected_link (AtkHyperlink *link)
