@@ -21,9 +21,6 @@
 
 #include <string.h>
 
-static gboolean  test_relation (void);
-static gboolean  test_role (void);
-
 static gboolean
 test_relation (void)
 {
@@ -165,67 +162,6 @@ test_relation (void)
   return TRUE;
 }
 
-static gboolean
-test_role (void)
-{
-  AtkRole role1, role2;
-  const gchar *name;
-
-  name = atk_role_get_name (ATK_ROLE_PAGE_TAB);
-  g_return_val_if_fail (name, FALSE);
-  if (strcmp (name, "page tab") != 0)
-    {
-      g_print ("Unexpected name for ATK_ROLE_PAGE_TAB %s\n", name);
-      return FALSE;
-    }
-
-  name = atk_role_get_name (ATK_ROLE_LAYERED_PANE);
-  g_return_val_if_fail (name, FALSE);
-  if (strcmp (name, "layered pane") != 0)
-    {
-      g_print ("Unexpected name for ATK_ROLE_LAYERED_PANE %s\n", name);
-      return FALSE;
-    }
-
-  role1 = atk_role_for_name ("list item");
-  if (role1 != ATK_ROLE_LIST_ITEM)
-    {
-      g_print ("Unexpected role for list item\n");
-      return FALSE;
-    }
-
-  role1 = atk_role_register ("test-role");
-  name = atk_role_get_name (role1);
-  g_return_val_if_fail (name, FALSE);
-  if (strcmp (name, "test-role") != 0)
-    {
-      g_print ("Unexpected name for test-role %s\n", name);
-      return FALSE;
-    }
-  role2 = atk_role_for_name ("test-role");
-  if (role1 != role2)
-  {
-    g_print ("Unexpected role for test-role\n");
-    return FALSE;
-  }
-  role2 = atk_role_for_name ("TEST_ROLE");
-  if (role2 != 0)
-    {
-      g_print ("Unexpected role for TEST_ROLE\n");
-      return FALSE;
-    }
-  /*
-   * Check that a non-existent role returns NULL
-   */
-  name = atk_role_get_name (ATK_ROLE_LAST_DEFINED + 2);
-  if (name)
-    {
-      g_print ("Unexpected name for undefined role %s\n", name);
-      return FALSE;
-    }
-  return TRUE;
-}
-
 static gboolean
 test_text_attr (void)
 {
@@ -288,27 +224,24 @@ test_text_attr (void)
 }
 
 int
-gtk_module_init (gint  argc, 
-                 char* argv[])
+main (gint  argc,
+      char* argv[])
 {
   gboolean b_ret;
 
-  g_print("Relation test module loaded\n");
+  g_print("Starting Relation test suite\n");
 
   b_ret = test_relation ();
   if (b_ret)
     g_print ("Relation tests succeeded\n");
   else
     g_print ("Relation tests failed\n");
-  b_ret = test_role ();
-  if (b_ret)
-    g_print ("Role tests succeeded\n");
-  else
-    g_print ("Role tests failed\n");
+
   b_ret = test_text_attr ();
   if (b_ret)
     g_print ("Text Attribute tests succeeded\n");
   else
     g_print ("Text Attribute tests failed\n");
+
   return 0;
 }
